EXPORTS
	Write__5RPipeRC6TDesC8i @ 1 NONAME R3UNUSED ; RPipe::Write(TDesC8 const &, int)
	CancelSpaceAvailable__5RPipe @ 2 NONAME R3UNUSED ; RPipe::CancelSpaceAvailable(void)
	CancelWait__5RPipe @ 3 NONAME R3UNUSED ; RPipe::CancelWait(void)
	Close__5RPipe @ 4 NONAME R3UNUSED ; RPipe::Close(void)
	Create__5RPipeiR5RPipeT210TOwnerTypeT4 @ 5 NONAME ; RPipe::Create(int, RPipe &, RPipe &, TOwnerType, TOwnerType)
	Define__5RPipeRC7TDesC16i @ 6 NONAME R3UNUSED ; RPipe::Define(TDesC16 const &, int)
	Define__5RPipeRC7TDesC16iRC15TSecurityPolicy @ 7 NONAME R3UNUSED ; RPipe::Define(TDesC16 const &, int, TSecurityPolicy const &)
	Destroy__5RPipeRC7TDesC16 @ 8 NONAME R3UNUSED ; RPipe::Destroy(TDesC16 const &)
	Flush__5RPipe @ 9 NONAME R3UNUSED ; RPipe::Flush(void)
	HandleType__C5RPipe @ 10 NONAME R3UNUSED ; RPipe::HandleType(void) const
	Init__5RPipe @ 11 NONAME R3UNUSED ; RPipe::Init(void)
	MaxSize__5RPipe @ 12 NONAME R3UNUSED ; RPipe::MaxSize(void)
	NotifyDataAvailable__5RPipeR14TRequestStatus @ 13 NONAME R3UNUSED ; RPipe::NotifyDataAvailable(TRequestStatus &)
	NotifySpaceAvailable__5RPipeiR14TRequestStatus @ 14 NONAME R3UNUSED ; RPipe::NotifySpaceAvailable(int, TRequestStatus &)
	Open__5RPipeG12RMessagePtr2i10TOwnerType @ 15 NONAME ; RPipe::Open(RMessagePtr2, int, TOwnerType)
	Open__5RPipeRC7TDesC16Q25RPipe5TMode @ 16 NONAME R3UNUSED ; RPipe::Open(TDesC16 const &, RPipe::TMode)
	Open__5RPipei10TOwnerType @ 17 NONAME R3UNUSED ; RPipe::Open(int, TOwnerType)
	ReadBlocking__5RPipeR5TDes8i @ 18 NONAME R3UNUSED ; RPipe::ReadBlocking(TDes8 &, int)
	Read__5RPipeR5TDes8i @ 19 NONAME R3UNUSED ; RPipe::Read(TDes8 &, int)
	Size__5RPipe @ 20 NONAME R3UNUSED ; RPipe::Size(void)
	Wait__5RPipeRC7TDesC16R14TRequestStatus @ 21 NONAME R3UNUSED ; RPipe::Wait(TDesC16 const &, TRequestStatus &)
	WriteBlocking__5RPipeRC6TDesC8i @ 22 NONAME R3UNUSED ; RPipe::WriteBlocking(TDesC8 const &, int)
	CancelDataAvailable__5RPipe @ 23 NONAME R3UNUSED ; RPipe::CancelDataAvailable(void)
	WaitForReader__5RPipeRC7TDesC16R14TRequestStatus @ 24 NONAME R3UNUSED ; RPipe::WaitForReader(TDesC16 const &, TRequestStatus &)
	WaitForWriter__5RPipeRC7TDesC16R14TRequestStatus @ 25 NONAME R3UNUSED ; RPipe::WaitForWriter(TDesC16 const &, TRequestStatus &)

